@@ -1,6 +1,5 @@
-test_that("custom tables", { 
-    skip_on_cran()
-    
+if(isTRUE(getOption("covr"))) { 
+
     context("custom tables")
     suppressWarnings(RNGversion("3.5.0"))
     
@@ -33,7 +32,7 @@ test_that("custom tables", {
         tab_stat_fun(w_mean) %>% 
         tab_pivot
     
-    expect_equal_to_reference(res, "rds/ctable0.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable0.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cols(vs) %>% 
@@ -42,7 +41,7 @@ test_that("custom tables", {
         tab_stat_fun(w_mean) %>% 
         tab_pivot
     
-    expect_equal_to_reference(res, "rds/ctable0.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable0.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_rows(am) %>% 
@@ -51,7 +50,7 @@ test_that("custom tables", {
         tab_stat_fun(w_mean) %>% 
         tab_pivot
     
-    expect_equal_to_reference(res, "rds/ctable0.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable0.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -60,7 +59,7 @@ test_that("custom tables", {
         tab_stat_fun(w_mean = w_mean) %>% 
         tab_pivot
     
-    expect_equal_to_reference(res, "rds/ctable1.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable1.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -68,7 +67,7 @@ test_that("custom tables", {
         tab_rows(am) %>% 
         tab_stat_fun("|" = w_mean) %>% 
         tab_pivot
-    expect_equal_to_reference(res, "rds/ctable2.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable2.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -77,7 +76,7 @@ test_that("custom tables", {
         tab_stat_fun("|" = w_mean, label = "Mean value") %>% 
         tab_pivot
     
-    expect_equal_to_reference(res, "rds/ctable3.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable3.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -86,7 +85,7 @@ test_that("custom tables", {
         tab_stat_fun("|" = w_mean, label = "Mean value") %>% 
         tab_pivot(stat_position = "inside_rows")
     
-    expect_equal_to_reference(res, "rds/ctable3.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable3.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -95,7 +94,7 @@ test_that("custom tables", {
         tab_stat_fun("|" = w_mean, label = "Mean value") %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable4.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable4.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -103,7 +102,7 @@ test_that("custom tables", {
         tab_rows(am) %>% 
         tab_stat_mean(label = "Mean value") %>% 
         tab_pivot()
-    expect_equal_to_reference(res, "rds/ctable3.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable3.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -112,7 +111,7 @@ test_that("custom tables", {
         tab_stat_mean(label = "Mean value") %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable4.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable4.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -123,7 +122,7 @@ test_that("custom tables", {
         tab_stat_valid_n() %>% 
         tab_pivot(stat_position = "inside_rows")
     
-    expect_equal_to_reference(res, "rds/ctable5.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable5.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -134,7 +133,7 @@ test_that("custom tables", {
         tab_stat_valid_n() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable6.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable6.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp) %>% 
@@ -144,9 +143,9 @@ test_that("custom tables", {
         tab_pivot()
     
     if(as.numeric(version$major) ==3 && as.numeric(version$minor)<4){
-        expect_equal_to_reference(res, "rds/ctable7.rds",  update = FALSE)
+        expect_known_value(res, "rds/ctable7.rds",  update = FALSE)
     } else {
-        expect_equal_to_reference(res, "rds/ctable7_R3.4.rds",  update = FALSE)
+        expect_known_value(res, "rds/ctable7_R3.4.rds",  update = FALSE)
     }
     
     res = mtcars %>% 
@@ -159,7 +158,7 @@ test_that("custom tables", {
         tab_stat_cases(total_row_position = "none") %>% 
         tab_pivot(stat_position = "inside_rows") 
     
-    expect_equal_to_reference(res, "rds/ctable8.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable8.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_total_row_position("none") %>% 
@@ -172,7 +171,7 @@ test_that("custom tables", {
         tab_stat_cases() %>% 
         tab_pivot(stat_position = "inside_rows") 
     
-    expect_equal_to_reference(res, "rds/ctable8.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable8.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_subgroup(vs == 0) %>% 
@@ -186,7 +185,7 @@ test_that("custom tables", {
         tab_stat_cases(total_row_position = "none") %>% 
         tab_pivot(stat_position = "inside_rows") 
     
-    expect_equal_to_reference(res, "rds/ctable8.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable8.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_subgroup(vs == 0) %>% 
@@ -199,7 +198,7 @@ test_that("custom tables", {
         tab_stat_cases(total_row_position = "none") %>% 
         tab_pivot(stat_position = "inside_rows") 
     
-    expect_equal_to_reference(res, "rds/ctable9.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable9.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(cyl) %>% 
@@ -209,7 +208,7 @@ test_that("custom tables", {
         tab_transpose() %>% 
         tab_sort_desc()
     
-    expect_equal_to_reference(res, "rds/ctable10.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable10.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, disp, hp) %>% 
@@ -220,7 +219,7 @@ test_that("custom tables", {
         tab_pivot() %>% 
         split_columns()
     
-    expect_equal_to_reference(res, "rds/ctable11.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable11.rds",  update = FALSE)
     
     set.seed(1)
     df = data.frame(area=rep(c('Area 1','Area 2'), each=6),
@@ -236,7 +235,7 @@ test_that("custom tables", {
         tab_stat_cpct_responses(total_row_position = "below", total_statistic = "u_responses") %>% 
         tab_pivot()
     
-    expect_equal_to_reference(res, "rds/ctable12.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable12.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(cyl, carb) %>% 
@@ -245,7 +244,7 @@ test_that("custom tables", {
         tab_stat_cpct() %>% 
         tab_pivot() 
     
-    expect_equal_to_reference(res, "rds/ctable13.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable13.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cols(total(), am %nest% vs) %>%
@@ -257,7 +256,7 @@ test_that("custom tables", {
         tab_stat_cpct() %>% 
         tab_pivot() 
     
-    expect_equal_to_reference(res, "rds/ctable14.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable14.rds",  update = FALSE)
     
     
     
@@ -271,7 +270,7 @@ test_that("custom tables", {
     }
     res = res %>% tab_pivot()
     
-    expect_equal_to_reference(res, "rds/ctable15.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable15.rds",  update = FALSE)
     
     
     res = mtcars %>% 
@@ -279,7 +278,7 @@ test_that("custom tables", {
         tab_cols(total(), am %nest% vs) %>%
         tab_stat_fun(w_mean, w_sd, w_n, method = list) %>% 
         tab_pivot()
-    expect_equal_to_reference(res, "rds/ctable16.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable16.rds",  update = FALSE)
     
     res = mtcars %>%
         tab_cells(cyl) %>%
@@ -288,7 +287,7 @@ test_that("custom tables", {
         tab_stat_rpct(total_row_position = "none", label = "row %") %>%
         tab_stat_tpct(total_row_position = "none", label = "table %") %>%
         tab_pivot(stat_position = "inside_columns")
-    expect_equal_to_reference(res, "rds/ctable17.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable17.rds",  update = FALSE)
     
     res = mtcars %>%
         tab_cells(cyl) %>%
@@ -298,7 +297,7 @@ test_that("custom tables", {
         tab_stat_rpct(label = "row %") %>%
         tab_stat_tpct(label = "table %") %>%
         tab_pivot(stat_position = "inside_columns")
-    expect_equal_to_reference(res, "rds/ctable17.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable17.rds",  update = FALSE)
     
     res = mtcars %>%
         tab_cells(cyl) %>%
@@ -308,7 +307,7 @@ test_that("custom tables", {
         tab_stat_rpct(total_row_position = "none", label = "row %") %>%
         tab_stat_tpct(total_row_position = "none", label = "table %") %>%
         tab_pivot(stat_position = "inside_rows")
-    expect_equal_to_reference(res, "rds/ctable18.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable18.rds",  update = FALSE)
     
     context("custom tables summary stats")
     
@@ -335,7 +334,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable19.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable19.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_weight(wt) %>% 
@@ -352,7 +351,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable19.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable19.rds",  update = FALSE)
     
     
     
@@ -370,7 +369,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable20.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable20.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, qsec, hp, disp) %>% 
@@ -387,7 +386,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable20.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable20.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_subgroup(!is.na(wt) & wt>0) %>% 
@@ -404,7 +403,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns")
     
-    expect_equal_to_reference(res, "rds/ctable20.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable20.rds",  update = FALSE)
     
     res1 = sheet(a = c(1, 2, 3, 4, 5), b = c(5, 5, 1, 2, NA)) %>% 
         tab_cells(a, b) %>% 
@@ -540,7 +539,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable20_1.rds",  update = FALSE
     )
@@ -552,7 +551,7 @@ test_that("custom tables", {
                                                     "w_cases", "w_responses", "w_cpct", "w_rpct", "w_tpct")
     )
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable20_1.rds",  update = FALSE
     )
@@ -564,7 +563,7 @@ test_that("custom tables", {
     )
     
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable20_1a.rds",  update = FALSE
     )
@@ -579,7 +578,7 @@ test_that("custom tables", {
         tab_stat_cases() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable20_1.rds",  update = FALSE
     )
@@ -595,7 +594,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable21.rds",  update = FALSE
     )
@@ -611,7 +610,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable22.rds",  update = FALSE
     )
@@ -626,7 +625,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable23.rds",  update = FALSE
     )
@@ -642,7 +641,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable24.rds",  update = FALSE
     )
@@ -657,7 +656,7 @@ test_that("custom tables", {
             )) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable25.rds",  update = FALSE
     )
@@ -679,7 +678,7 @@ test_that("custom tables", {
         tab_sort_asc() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable25_sorting.rds",  update = FALSE
     )
@@ -697,7 +696,7 @@ test_that("custom tables", {
         tab_sort_asc() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable25_sorting.rds",  update = FALSE
     )
@@ -716,7 +715,7 @@ test_that("custom tables", {
         tab_sort_asc() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable25_different_total.rds",  update = FALSE
     )
@@ -735,7 +734,7 @@ test_that("custom tables", {
         tab_sort_asc() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable25_different_total2.rds",  update = FALSE
     )
@@ -757,7 +756,7 @@ test_that("custom tables", {
         tab_stat_fun(my_fun = w_mean, w_median) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable26.rds",  update = FALSE
     )
@@ -769,7 +768,7 @@ test_that("custom tables", {
         tab_stat_fun_df(w_cor) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable27.rds",  update = FALSE
     )
@@ -780,7 +779,7 @@ test_that("custom tables", {
         tab_stat_fun_df(w_cor) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable28.rds",  update = FALSE
     )
@@ -791,7 +790,7 @@ test_that("custom tables", {
         tab_stat_cases() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable29.rds",  update = FALSE
     )
@@ -803,7 +802,7 @@ test_that("custom tables", {
         tab_stat_fun_df(sum = colSums, mean = colMeans, method = list) %>% 
         tab_pivot()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable30.rds",  update = FALSE
     )
@@ -822,7 +821,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_columns", stat_label = "outside")
     
-    expect_equal_to_reference(res, "rds/ctable31.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable31.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, qsec, hp, disp) %>% 
@@ -838,7 +837,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "inside_rows", stat_label = "outside")
     
-    expect_equal_to_reference(res, "rds/ctable32.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable32.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, qsec, hp, disp) %>% 
@@ -854,7 +853,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "outside_rows", stat_label = "outside")
     
-    expect_equal_to_reference(res, "rds/ctable33.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable33.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, qsec, hp, disp) %>% 
@@ -871,7 +870,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "outside_columns", stat_label = "outside")
     
-    expect_equal_to_reference(res, "rds/ctable34.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable34.rds",  update = FALSE)
     
     mtcars2 = mtcars
     mtcars2$am = unvr(mtcars2$am)
@@ -890,7 +889,7 @@ test_that("custom tables", {
         tab_stat_max() %>% 
         tab_pivot(stat_position = "outside_columns", stat_label = "outside")
     
-    expect_equal_to_reference(res, "rds/ctable35.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable35.rds",  update = FALSE)
     
     mtcars2$vs = unvr(mtcars2$vs)
     res = mtcars2 %>% 
@@ -899,7 +898,7 @@ test_that("custom tables", {
         tab_stat_cpct() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(res, "rds/ctable36.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable36.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_cells(mpg, qsec, hp, disp) %>% 
@@ -966,7 +965,7 @@ test_that("custom tables", {
         tab_stat_mean() %>% 
         tab_pivot()
     
-    expect_equal_to_reference(res, "rds/ctable37.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable37.rds",  update = FALSE)
     
     res = mtcars %>% 
         tab_total_row_position("above") %>% 
@@ -1098,7 +1097,7 @@ test_that("custom tables", {
         tab_row_label("### the end ###") %>% 
         tab_pivot() 
     
-    expect_equal_to_reference(res, "rds/ctable38.rds",  update = FALSE)
+    expect_known_value(res, "rds/ctable38.rds",  update = FALSE)
     
     
     
@@ -1126,7 +1125,7 @@ test_that("custom tables", {
         tab_pivot() %>% 
         make_subheadings()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable40.rds",  update = FALSE
     )
@@ -1147,9 +1146,9 @@ test_that("custom tables", {
         tab_pivot() %>% 
         make_subheadings()
     
-    expect_equal_to_reference(
+    expect_known_value(
         res,
         "rds/ctable41.rds",  update = FALSE
     )
     
-})
\ No newline at end of file
+}
\ No newline at end of file
